@@ -8,6 +8,7 @@ from hypernetx.classes import *
 from hypernetx.reports import *
 from hypernetx.drawing import *
 from hypernetx.algorithms import *
-from hypernetx.algorithms.contagion import *
 from hypernetx.utils import *
 from hypernetx.utils.toys import *
+
+__version__ = "2.0.5"
