@@ -11,14 +11,12 @@ constructing the corresponding graph of the matrix. We then use existing graph m
 on this representation of the hypergraph. In essence we construct an *s*-line graph
 corresponding to the hypergraph on which to apply our methods.
 
-S-Metrics for hypergraphs are discussed in depth in:        
+S-Metrics for hypergraphs are discussed in depth in:
 *Aksoy, S.G., Joslyn, C., Ortiz Marrero, C. et al. Hypernetwork science via high-order hypergraph walks.
 EPJ Data Sci. 9, 16 (2020). https://doi.org/10.1140/epjds/s13688-020-00231-0*
 
 """
 
-import numpy as np
-from collections import defaultdict
 import networkx as nx
 import warnings
 import sys
@@ -33,18 +31,8 @@ except:
 
 sys.setrecursionlimit(10000)
 
-__all__ = [
-    "s_betweenness_centrality",
-    "s_harmonic_closeness_centrality",
-    "s_harmonic_centrality",
-    "s_closeness_centrality",
-    "s_eccentricity",
-]
 
-
-def _s_centrality(
-    func, H, s=1, edges=True, f=None, return_singletons=True, use_nwhy=True, **kwargs
-):
+def _s_centrality(func, H, s=1, edges=True, f=None, return_singletons=True, **kwargs):
     """
     Wrapper for computing s-centrality either in NetworkX or in NWHy
 
@@ -62,8 +50,6 @@ def _s_centrality(
         Identifier of node or edge of interest for computing centrality
     return_singletons : bool, optional
         If True will return 0 value for each singleton in the s-linegraph
-    use_nwhy : bool, optional
-        If True will attempt to use nwhy centrality methods if availaable
     **kwargs
         Centrality metric specific keyword arguments to be passed to func
 
@@ -84,44 +70,25 @@ def _s_centrality(
             return {f: 0}
 
     stats = dict()
-    if H.isstatic:
-        for h in comps:
-            if edges:
-                vertices = h.edges
-            else:
-                vertices = h.nodes
+    for h in comps:
+        if edges:
+            vertices = h.edges
+        else:
+            vertices = h.nodes
 
-            if h.shape[edges * 1] == 1:
-                stats.update({v: 0 for v in vertices})
-            elif use_nwhy and nwhy_available and h.nwhy:
-                g = h.get_linegraph(s=s, edges=edges, use_nwhy=True)
-                stats.update(dict(zip(vertices, func(g, **kwargs))))
-            else:
-                g = h.get_linegraph(s=s, edges=edges, use_nwhy=False)
-                stats.update(
-                    {
-                        h.get_name(k, edges=edges): v
-                        for k, v in func(g, **kwargs).items()
-                    }
-                )
-            if f:
-                return {f: stats[f]}
-    else:
-        for h in comps:
-            if edges:
-                A, Adict = h.edge_adjacency_matrix(s=s, index=True)
-            else:
-                A, Adict = h.adjacency_matrix(s=s, index=True)
-            g = nx.from_scipy_sparse_matrix(A)
-            stats.update({Adict[k]: v for k, v in func(g, **kwargs).items()})
-            if f:
-                return {f: stats[f]}
+        if h.shape[edges * 1] == 1:
+            stats = {v: 0 for v in vertices}
+        else:
+            g = h.get_linegraph(s=s, edges=edges)
+            stats.update({k: v for k, v in func(g, **kwargs).items()})
+        if f:
+            return {f: stats[f]}
 
     return stats
 
 
 def s_betweenness_centrality(
-    H, s=1, edges=True, normalized=True, return_singletons=True, use_nwhy=True
+    H, s=1, edges=True, normalized=True, return_singletons=True
 ):
     r"""
     A centrality measure for an s-edge(node) subgraph of H based on shortest paths.
@@ -161,18 +128,13 @@ def s_betweenness_centrality(
         A dictionary of s-betweenness centrality value of the edges.
 
     """
-    if use_nwhy and nwhy_available and H.nwhy:
-        func = partial(nwhy.Slinegraph.s_betweenness_centrality, normalized=False)
-    else:
-        use_nwhy = False
-        func = partial(nx.betweenness_centrality, normalized=False)
+    func = partial(nx.betweenness_centrality, normalized=False)
     result = _s_centrality(
         func,
         H,
         s=s,
         edges=edges,
         return_singletons=return_singletons,
-        use_nwhy=use_nwhy,
     )
 
     if normalized and H.shape[edges * 1] > 2:
@@ -182,9 +144,7 @@ def s_betweenness_centrality(
         return result
 
 
-def s_closeness_centrality(
-    H, s=1, edges=True, return_singletons=True, source=None, use_nwhy=True
-):
+def s_closeness_centrality(H, s=1, edges=True, return_singletons=True, source=None):
     r"""
     In a connected component the reciprocal of the sum of the distance between an
     edge(node) and all other edges(nodes) in the component times the number of edges(nodes)
@@ -211,8 +171,6 @@ def s_closeness_centrality(
         Indicates if method should return values for singleton components.
     source : str, optional
         Identifier of node or edge of interest for computing centrality
-    use_nwhy : bool, optional
-        If true will use the :ref:`NWHy library <nwhy>` if available.
 
     Returns
     -------
@@ -221,11 +179,7 @@ def s_closeness_centrality(
         If source=None a dictionary of values for each s-edge in H is returned.
         If source then a single value is returned.
     """
-    if use_nwhy and nwhy_available and H.nwhy:
-        func = partial(nwhy.Slinegraph.s_closeness_centrality)
-    else:
-        use_nwhy = False
-        func = partial(nx.closeness_centrality)
+    func = partial(nx.closeness_centrality)
     return _s_centrality(
         func,
         H,
@@ -233,14 +187,13 @@ def s_closeness_centrality(
         edges=edges,
         return_singletons=return_singletons,
         f=source,
-        use_nwhy=use_nwhy,
     )
 
 
-def s_harmonic_closeness_centrality(H, s=1, edge=None, use_nwhy=True):
+def s_harmonic_closeness_centrality(H, s=1, edge=None):
     msg = """
-    s_harmonic_closeness_centrality is being replaced with s_harmonic_centrality 
-    and will not be available in future releases. 
+    s_harmonic_closeness_centrality is being replaced with s_harmonic_centrality
+    and will not be available in future releases.
     """
     warnings.warn(msg)
     return s_harmonic_centrality(H, s=s, edges=True, normalized=True, source=edge)
@@ -253,7 +206,6 @@ def s_harmonic_centrality(
     source=None,
     normalized=False,
     return_singletons=True,
-    use_nwhy=True,
 ):
     r"""
     A centrality measure for an s-edge subgraph of H. A value equal to 1 means the s-edge
@@ -284,8 +236,6 @@ def s_harmonic_centrality(
         Indicates if method should return values for singleton components.
     source : str, optional
         Identifier of node or edge of interest for computing centrality
-    use_nwhy : bool, optional
-        If true will use the :ref:`NWHy library <nwhy>` if available.
 
     Returns
     -------
@@ -296,34 +246,41 @@ def s_harmonic_centrality(
 
     """
 
-    if use_nwhy and nwhy_available and H.nwhy:
-        func = partial(nwhy.Slinegraph.s_harmonic_closeness_centrality)
-    else:
-        use_nwhy = False
-        func = partial(nx.harmonic_centrality)
-    result = _s_centrality(
-        func,
-        H,
-        s=s,
-        edges=edges,
-        return_singletons=return_singletons,
-        f=source,
-        use_nwhy=use_nwhy,
-    )
+    # func = partial(nx.harmonic_centrality)
+    # result = _s_centrality(
+    #     func,
+    #     H,
+    #     s=s,
+    #     edges=edges,
+    #     return_singletons=return_singletons,
+    #     f=source,
+    # )
+    g = H.get_linegraph(s=s, edges=edges)
+    result = nx.harmonic_centrality(g)
 
     if normalized and H.shape[edges * 1] > 2:
         n = H.shape[edges * 1]
-        return {k: v * 2 / ((n - 1) * (n - 2)) for k, v in result.items()}
+        factor = 2 / ((n - 1) * (n - 2))
     else:
-        return result
+        factor = 1
+
+    if source:
+        return result[source] * factor
+    else:
+        return {k: v * factor for k, v in result.items()}
+
+    # if normalized and H.shape[edges * 1] > 2:
+    #     n = H.shape[edges * 1]
+    #     result = {k: v * 2 / ((n - 1) * (n - 2)) for k, v in result.items()}
+    # else:
+    #     return result
 
 
-def s_eccentricity(
-    H, s=1, edges=True, source=None, return_singletons=True, use_nwhy=True
-):
+def s_eccentricity(H, s=1, edges=True, source=None, return_singletons=True):
     r"""
-    The length of the longest shortest path from a vertex $u$ to every other vertex in the linegraph.
-    $V$ = set of vertices in the linegraph
+    The length of the longest shortest path from a vertex $u$ to every other vertex in
+    the s-linegraph.
+    $V$ = set of vertices in the s-linegraph
     $d$ = shortest path distance
 
     .. math::
@@ -342,8 +299,6 @@ def s_eccentricity(
         Indicates if method should return values for singleton components.
     source : str, optional
         Identifier of node or edge of interest for computing centrality
-    use_nwhy : bool, optional
-        If true will use the :ref:`NWHy library <nwhy>` if available.
 
     Returns
     -------
@@ -351,30 +306,33 @@ def s_eccentricity(
         returns the s-eccentricity value of the edges(nodes).
         If source=None a dictionary of values for each s-edge in H is returned.
         If source then a single value is returned.
+        If the s-linegraph is disconnected, np.inf is returned.
 
     """
-    if use_nwhy and nwhy_available and H.nwhy:
-        func = nwhy.Slinegraph.s_eccentricity
-    else:
-        use_nwhy = False
-        func = nx.eccentricity
 
-    if source is not None:
-        return _s_centrality(
-            func,
-            H,
-            s=s,
-            edges=edges,
-            f=source,
-            return_singletons=return_singletons,
-            use_nwhy=use_nwhy,
-        )
+    g = H.get_linegraph(s=s, edges=edges)
+    result = nx.eccentricity(g)
+    if source:
+        return result[source]
     else:
-        return _s_centrality(
-            func,
-            H,
-            s=s,
-            edges=edges,
-            return_singletons=return_singletons,
-            use_nwhy=use_nwhy,
-        )
+        return result
+
+    # func = nx.eccentricity
+
+    # if source is not None:
+    #     return _s_centrality(
+    #         func,
+    #         H,
+    #         s=s,
+    #         edges=edges,
+    #         f=source,
+    #         return_singletons=return_singletons,
+    #     )
+    # else:
+    #     return _s_centrality(
+    #         func,
+    #         H,
+    #         s=s,
+    #         edges=edges,
+    #         return_singletons=return_singletons,
+    #     )
