@@ -1,24 +1,26 @@
 # Copyright © 2018 Battelle Memorial Institute
 # All rights reserved.
 
-import numpy as np
 import pandas as pd
 from itertools import islice, chain, repeat
 
-import networkx as nx
-
 import matplotlib.pyplot as plt
 
 import hypernetx as hnx
 
-__all__ = ["LesMis", "lesmis_hypergraph_from_df", "book_tour"]
-
 
 class LesMis(object):
     def __init__(self):
         self.volumes = pd.DataFrame.from_dict(volume_names, orient="index")
 
-        accents = {"\`e": "è", "\\`e": "è", "'e": "é", "\\c{c}": "ç", "\^o": "ô"}
+        accents = {
+            r"\`e": "è",
+            r"\\'e": "è",
+            r"\\`e": "è",
+            r"'e": "é",
+            r"\\c{c}": "ç",
+            r"\^o": "ô",
+        }
         for k, v in accents.items():
             self.names = names.replace(k, v)
 
@@ -114,7 +116,7 @@ def get_scene_data():
 
 
 # LesMis Data:
-names = """AZ Anzelma, daughter of TH and TM
+names = r"""AZ Anzelma, daughter of TH and TM
 BA Bahorel, `Friends of the ABC' cutup
 BB Babet, tooth-pulling bandit of Paris
 BJ Brujon, notorious criminal
